declare const CooGL: any;

/** 地图属性 */
declare type MapViewProps = {
  /** 暂定20级 */
  zoom?: number;
  /** 地图中心点 */
  center: { x: number; y: number; z?: number };
  /** 是否显示默认组件 */
  showComponent?: boolean;
  /** 是否显示自定义组件  */
  showCustomComponent?: boolean;
  /** 显示2d还是3d地图 */
  mode?: '2D' | '3D';
  /** 包围盒的点位数据,如果该数据不传递则不会显示home 功能 */
  boundingSpherePoints?: [number, number][];
};
/** Map api 文档  @see http://123.157.223.158:30017/Documentation/MapViewer.html */
declare type MapViewMethods = any;

/** 定义全量事件 */
type OnPrefixEventHandlers = {
  [K in string as `on${K}`]: (e?: MouseEvent) => void;
};

/** 自定义覆盖物 */
declare interface CustomOverlayProps extends OnPrefixEventHandlers {
  /** 覆盖物位置 */
  position: number[];
  /** 偏移量 */
  offset?: { top?: number; left?: number };

  onClick?: () => void;
}

/** 多边形属性 */
declare type PolygonProps = {
  /** 坐标点集合 */
  points: number[][];
  /** 边框颜色 */
  strokeColor?: string;
  /** 边框宽度 */
  strokeWidth?: number;
  /** 填充颜色 */
  fillColor?: string;
  /** 填充透明度 */
  fillOpacity?: number;
};

/** maker标记属性 */
declare type MakerProps = {
  /** 图片地址 */
  icon: string;
  /** 位置 */
  position: number[];
  /** maker点击事件 */
  onClick?: () => void;
};

/** 文本标准props */
declare type LabelProps = {
  /** 图片地址 */
  text: string;
  /** 位置 */
  position: number[];
  /** maker点击事件 */
  onClick?: () => void;
  /** 是否显示背景 */
  showBackground?: boolean;
  /** 背景颜色 */
  backgroundColor?: string;
  /** 背景padding */
  backgroundPadding?: { x: 8; y: 8 };
};

/** 线props */
declare type PolylineProps = {
  /** 线宽 */
  width: string;
  /** 坐标集合 */
  points: number[][];
  /** 线的颜色 */
  lineColor: string;
  /**
   * 材质,不提供默认为实线
   * @param flowLine 流动纹理线
   * @param flowLineSegment: 流动纹理线段
   * @param emptyLine: 虚线
   * @param arrowLine 箭头线
   *
   *   */
  material?: 'flowLine' | 'flowLineSegment' | 'emptyLine' | 'arrowLine';

  /** 线点击事件 */
  onClick?: () => void;
};
