// 计算两个经纬度之间的距离（单位：公里）
function haversine(
  lat1: number,
  lon1: number,
  lat2: number,
  lon2: number,
): number {
  const R = 6371; // 地球半径，单位为公里
  const dlat = (lat2 - lat1) * (Math.PI / 180); // 纬度差转换为弧度
  const dlon = (lon2 - lon1) * (Math.PI / 180); // 经度差转换为弧度
  const a =
    Math.sin(dlat / 2) ** 2 +
    Math.cos(lat1 * (Math.PI / 180)) *
      Math.cos(lat2 * (Math.PI / 180)) *
      Math.sin(dlon / 2) ** 2; // Haversine公式
  const c = 2 * Math.asin(Math.sqrt(a)); // 计算角度
  return R * c; // 返回距离
}

// 计算给定经纬度坐标集的包围圈的中心点及半径
export function calculateBoundingCircle(coordinates: [number, number][]): {
  center: [number, number];
  radius: number;
} {
  let sumLat = 0; // 纬度总和
  let sumLon = 0; // 经度总和
  let maxDistance = 0; // 最大距离
  const numberOfPoints = coordinates.length; // 坐标点数量

  // 计算所有点的经纬度总和
  for (const [lat, lon] of coordinates) {
    sumLat += lat;
    sumLon += lon;
  }

  // 计算中心点的经纬度
  const centerLat = sumLat / numberOfPoints;
  const centerLon = sumLon / numberOfPoints;

  // 计算每个点到中心点的距离，并找出最大距离
  for (const [lat, lon] of coordinates) {
    const distance = haversine(centerLat, centerLon, lat, lon);
    if (distance > maxDistance) {
      maxDistance = distance; // 更新最大距离
    }
  }

  // 返回中心点和半径
  return { center: [centerLat, centerLon], radius: maxDistance };
}
