import CustomMap from '@/components/CustomMap';
import BMapService from '@/utils/mapService';
import { getColorByIndex } from '@/utils/ui';
import { useModel } from '@umijs/max';
import { Space } from 'antd';
import React, { CSSProperties, Fragment, useEffect, useRef } from 'react';
import DistrictDetailBar from '../DIstrictDetailBar';
import styles from './index.less';

/** 地图 */
const DistrictMap: React.FC = () => {
  /** @description store */
  const { selectDistrict, areaListDto } = useModel('regionalIndex');

  const MapRef = useRef<any>();

  /**
   * @description 设置地图视野
   */
  const setViewport = () => {
    const points = areaListDto
      .map((item) => {
        return BMapService.buildPoints(item.points);
      })
      .flat(1);

    // const map = MapRef.current?.map as BMapGL.Map;
    // if (map) {
    //   map.setViewport(points);
    // }
  };

  const addZoom = () => {
    // const map = MapRef.current?.map as BMapGL.Map;
    // map.centerAndZoom(map.getCenter(), map.getZoom() + 1);
  };

  const reduceZoom = () => {
    // const map = MapRef.current?.map as BMapGL.Map;
    // map.centerAndZoom(map.getCenter(), map.getZoom() - 1);
  };

  /** @description 移动视角到能显示全部覆盖物 */
  useEffect(() => {
    setViewport();
  }, [MapRef.current]);

  console.log(areaListDto);

  return (
    <div className={styles.container}>
      <CustomMap.MapView
        zoom={13}
        ref={MapRef}
        center={{ x: 104.066349, y: 30.658842 }}
      >
        {!selectDistrict ? (
          <Fragment>
            {areaListDto.map((item, index) => {
              return (
                <CustomMap.Polygon
                  fillColor={getColorByIndex(Number(item.qualitySign))!}
                  key={index}
                  strokeColor="#fff"
                  points={item.points}
                  strokeWidth={2}
                  fillOpacity={0.2}
                ></CustomMap.Polygon>
              );
            })}
            {areaListDto.map((item, index) => {
              const point = [Number(item.centerX), Number(item.centerY)];

              return (
                <CustomMap.CustomOverlay key={index} position={point}>
                  <div
                    className={styles.indexMarker}
                    style={
                      BMapService.getMakerCSS(
                        Number(item.qualitySign),
                      ) as CSSProperties
                    }
                  >
                    {Number(item.qualitySign)}
                  </div>
                </CustomMap.CustomOverlay>
              );
            })}
          </Fragment>
        ) : undefined}
      </CustomMap.MapView>
      {selectDistrict && (
        <div className={styles.districtName}>{selectDistrict.objectName}</div>
      )}
      <div className={styles.statusBar}>
        <Space>
          <div className={styles.mark} style={{ backgroundColor: '#F24F4F' }} />
          <div>应急态 &lt;60</div>
        </Space>
        <Space>
          <div className={styles.mark} style={{ backgroundColor: '#FFA81A' }} />
          <div>预警态 &lt;85</div>
        </Space>
        <Space>
          <div className={styles.mark} style={{ backgroundColor: '#00B9FF' }} />
          <div>标准态 85-95</div>
        </Space>
        <Space>
          <div className={styles.mark} style={{ backgroundColor: '#57EF58' }} />
          <div>理想态 &gt;95</div>
        </Space>
      </div>

      {selectDistrict && <DistrictDetailBar></DistrictDetailBar>}
    </div>
  );
};

export default DistrictMap;
